

// link the DirectX libraries
#pragma comment(lib,"dxguid.lib")
#pragma comment(lib,"dinput.lib")
#pragma comment(lib,"dinput8.lib")

#define WIN32_LEAN_AND_MEAN
#include <Windows.h>

#define DIRECTINPUT_VERSION 0x0800
#include <dinput.h>
#include <iostream>


/// a pointer to the Direct Input interface
LPDIRECTINPUT8       g_pDI              = NULL; 

/// a pointer to the keyboard interface
LPDIRECTINPUTDEVICE8 g_pKeyboard		= NULL;

/// an array to store the states of all the keys
bool     g_key_buffer[256]={0};

//--------------------------------------------------------------------------	FreeInput()
/// \brief	This function is called to free direct input and release the
///			interface to the keyboard
/// \return	true if OK
///
bool FreeInput() {
	g_pKeyboard->Unacquire();
	g_pKeyboard->Release();
	g_pDI->Release();
	g_pDI=0;
	g_pKeyboard=0;
	return true;
}
//--------------------------------------------------------------------------	InitInput()
/// \brief	This function initialises Direct Input and a keyboard
/// \return	true if OK
///
bool InitInput()
{
	HRESULT hr;

	//	Create an interface to Direct Input
	//
	if( FAILED( hr = DirectInput8Create( GetModuleHandle(NULL), DIRECTINPUT_VERSION,
				IID_IDirectInput8, (VOID**)&g_pDI, NULL ) ) )
		return false;

	// create the keyboard device. g_pKeyboard will now give us access to the 
	// keyboard attached to the system
	// 
	hr = g_pDI->CreateDevice(GUID_SysKeyboard, &g_pKeyboard, NULL); 

	// if failed return error
	//
	if FAILED(hr) { 
		FreeInput();
		return false; 
	} 

	// set the type of input controller we want - keyboard please
	hr = g_pKeyboard->SetDataFormat(&c_dfDIKeyboard); 

	if FAILED(hr) { 
		
		return false; 
	} 
	
	// acquire the keyboard
	hr = g_pKeyboard->Acquire(); 

	if FAILED(hr) { 
		std::cerr << "SHIT INPUT" << std::endl;
		return false; 
	} 

	return true;
}

//--------------------------------------------------------------------------	PollKey()
/// \brief	This function queries the current state of a key to see if it's
///			pressed or not. 
/// \param	key	-	the code of the Direct X virtual key code
/// \return	true if held
///
bool PollKey(short key) {
    return g_key_buffer[key];
}

//--------------------------------------------------------------------------	UpdateInput()
/// \brief	This function simply queries the state of the directX keyboard 
///			at the current moment in time. This should be called once in the 
///			update for the game engine.
///
void UpdateInput() {
	HRESULT hr;

	// this returns an array of 256 key states of the keyboard
	hr = g_pKeyboard->GetDeviceState(sizeof(bool)*256,(LPVOID)&g_key_buffer);
	if( FAILED(hr) ) 
	{
		// DirectInput may be telling us that the input stream has been
		// interrupted.  We aren't tracking any state between polls, so
		// we don't have any special reset that needs to be done.
		// We just re-acquire and try again.

		// If input is lost then acquire and keep trying 
		hr = g_pKeyboard->Acquire();
		while( hr == DIERR_INPUTLOST ) 
			hr = g_pKeyboard->Acquire();
	} 
}
