//----------------------------------------------------------------------------------------
/// \file	keys.h
/// \author	Rob Bateman
/// \date	12-jan-2004
/// \brief	This is a simple example of how to access Direct Input within your Win32
///			glut programs. This *may* provide you with some performance benefits over
///			glut alone, however it does loose portability :(
///
//----------------------------------------------------------------------------------------



#ifndef __DX_KEYS__H__
#define __DX_KEYS__H__


#define WIN32_LEAN_AND_MEAN
#include <Windows.h>

#define DIRECTINPUT_VERSION 0x0800
#include <dinput.h>

//--------------------------------------------------------------------------	FreeInput()
/// \brief	This function is called to free direct input and release the
///			interface to the keyboard
/// \return	true if OK
///
bool FreeInput() ;

//--------------------------------------------------------------------------	InitInput()
/// \brief	This function initialises Direct Input and a keyboard
/// \return	true if OK
///
bool InitInput() ;

//--------------------------------------------------------------------------	PollKey()
/// \brief	This function queries the current state of a key to see if it's
///			pressed or not. 
/// \param	key	-	the code of the Direct X virtual key code
/// \return	true if held
///
bool PollKey(short key);

//--------------------------------------------------------------------------	UpdateInput()
/// \brief	This function simply queries the state of the directX keyboard 
///			at the current moment in time. This should be called once in the 
///			update for the game engine.
///
void UpdateInput();

#endif
