//------------------------------------------------------------
/// \file	Main.cpp
/// \author	Rob Bateman
/// \date	9-feb-2005
/// \brief	This shows how to make use of Direct Input for 
///			keyboard input within glut applications.
//------------------------------------------------------------

#include <stdlib.h>
#include <math.h>
#include <iostream>
#include <GL/glut.h>

#include "keys.h"

/// the current position of the object
float position[2]={0,0};

//------------------------------------------------------------	OnReshape()
//
void OnReshape(int w, int h)
{
	if (h==0)
		h=1;

	// set the drawable region of the window
	glViewport(0,0,w,h);

	// set up the projection matrix 
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();

	// just use a perspective projection
	glOrtho(-100,100,-100,100,-100,100);

	// go back to modelview matrix so we can move the objects about
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
}


//------------------------------------------------------------	OnDraw()
//
void OnDraw() {

	// clear the screen & depth buffer
	glClear(GL_DEPTH_BUFFER_BIT|GL_COLOR_BUFFER_BIT);

	// clear the previous transform
	glLoadIdentity();

	// move the player to the correct location
	glTranslatef(position[0],position[1],0);

	// draw some object to represent our player
	glutWireSphere(3,10,10);

	// currently we've been drawing to the back buffer, we need
	// to swap the back buffer with the front one to make the image visible
	glutSwapBuffers();
}


//------------------------------------------------------------	OnInit()
//
void OnInit() {

	// first initialise Direct Input or the linux joystick lib
	if (!InitInput()) {
		std::cerr << "Failed to initialise the DX keyboard\n";
		exit(0);
	}

}

//------------------------------------------------------------	OnExit()
//
void OnExit() {

	// make sure we clean up directX and the linux joystick lib
	FreeInput();
}

//------------------------------------------------------------	OnIdle()
//
void OnIdle() {

	// update all connected joypads
	UpdateInput();


	if(PollKey(DIK_LEFT)) {
		position[0]-=0.02;

	}
	if(PollKey(DIK_RIGHT)) {
		position[0]+=0.02;

	}
	if(PollKey(DIK_UP)) {
		position[1]+=0.02;

	}
	if(PollKey(DIK_DOWN)) {
		position[1]-=0.02;

	}

	// redraw the screen
	glutPostRedisplay();
}


//------------------------------------------------------------	main()
//
int main(int argc,char** argv) {

	// initialise glut
	glutInit(&argc,argv);

	// request a depth buffer, RGBA display mode, and we want double buffering
	glutInitDisplayMode(GLUT_RGB|GLUT_DOUBLE);

	// set the initial window size
	glutInitWindowSize(640,480);

	// create the window
	glutCreateWindow("DX Keyboard in glut");

	// set the function to use to draw our scene
	glutDisplayFunc(OnDraw);

	// set the function to handle changes in screen size
	glutReshapeFunc(OnReshape);

	// set the idle callback
	glutIdleFunc(OnIdle);
	
	// run our custom initialisation
	OnInit();

	// set the function to be called when we exit
	atexit(OnExit);

	// this function runs a while loop to keep the program running.
	glutMainLoop();
	return 0;
}
